@@ -20,6 +20,7 @@
 
 /**
  * SECTION:gescontainer
+ * @title: GESContainer
  * @short_description: Base Class for objects responsible for controlling other
  * GESTimelineElement-s
  */
@@ -280,9 +281,8 @@ _lookup_child (GESTimelineElement * self, const gchar * prop_name,
 {
   GList *tmp;
 
-  /* FIXME Implement a synthax to precisely get properties by path */
+  /* FIXME Implement a syntax to precisely get properties by path */
   for (tmp = GES_CONTAINER_CHILDREN (self); tmp; tmp = tmp->next) {
-
     if (ges_timeline_element_lookup_child (tmp->data, prop_name, child, pspec))
       return TRUE;
   }
@@ -366,9 +366,12 @@ _dispose (GObject * object)
 {
   GList *tmp;
   GESContainer *self = GES_CONTAINER (object);
-  GList *children = ges_container_get_children (self, FALSE);
+  GList *children;
 
-  for (tmp = children; tmp; tmp = tmp->next)
+  _ges_container_sort_children (self);
+  children = ges_container_get_children (self, FALSE);
+
+  for (tmp = g_list_last (children); tmp; tmp = tmp->prev)
     ges_container_remove (self, tmp->data);
 
   g_list_free_full (children, gst_object_unref);
